from __future__ import unicode_literals
import os
import random
import contextlib
import shutil
import pytest
import tempfile
from pathlib import Path


import pathlib
from ...gold import GoldParse
from ...pipeline import EntityRecognizer
from ...language import Language

try:
    unicode
except NameError:
    unicode = str


@pytest.fixture
def train_data():
    return [
            ["hey",[]],
            ["howdy",[]],
            ["hey there",[]],
            ["hello",[]],
            ["hi",[]],
            ["i'm looking for a place to eat",[]],
            ["i'm looking for a place in the north of town",[[31,36,"location"]]],
            ["show me chinese restaurants",[[8,15,"cuisine"]]],
            ["show me chines restaurants",[[8,14,"cuisine"]]],
    ]


@contextlib.contextmanager
def temp_save_model(model):
    model_dir = Path(tempfile.mkdtemp())
    model.save_to_directory(model_dir)
    yield model_dir
    shutil.rmtree(model_dir.as_posix())


# TODO: Fix when saving/loading is fixed.
@pytest.mark.xfail
def test_issue999(train_data):
    '''Test that adding entities and resuming training works passably OK.
    There are two issues here:

    1) We have to readd labels. This isn't very nice.
    2) There's no way to set the learning rate for the weight update, so we
        end up out-of-scale, causing it to learn too fast.
    '''
    nlp = Language(pipeline=[])
    nlp.entity = EntityRecognizer(nlp.vocab, features=Language.Defaults.entity_features)
    nlp.pipeline.append(nlp.entity)
    for _, offsets in train_data:
        for start, end, ent_type in offsets:
            nlp.entity.add_label(ent_type)
    nlp.entity.model.learn_rate = 0.001
    for itn in range(100):
        random.shuffle(train_data)
        for raw_text, entity_offsets in train_data:
            doc = nlp.make_doc(raw_text)
            gold = GoldParse(doc, entities=entity_offsets)
            loss = nlp.entity.update(doc, gold)

    with temp_save_model(nlp) as model_dir:
        nlp2 = Language(path=model_dir)

    for raw_text, entity_offsets in train_data:
        doc = nlp2(raw_text)
        ents = {(ent.start_char, ent.end_char): ent.label_ for ent in doc.ents}
        for start, end, label in entity_offsets:
            if (start, end) in ents:
                assert ents[(start, end)] == label
                break
        else:
            if entity_offsets:
                raise Exception(ents)



# coding: utf8
from __future__ import unicode_literals


VERBS_IRREG = {
     "είσαι": ("είμαι",),
     "είναι": ("είμαι",),
     "είμαστε": ("είμαι",),
     "είστε": ("είμαι",),
     "είσαστε": ("είμαι",),
     "ήμουν": ("είμαι",),
     "ήσουν": ("είμαι",),
     "ήταν": ("είμαι",),
     "ήμαστε": ("είμαι",),
     "ήμασταν": ("είμαι",),
     "ήταν": ("είμαι",),
     "είπα": ("λέω",),
     "είπες": ("λέω",),
     "είπε": ("λέω",),
     "είπαμε": ("λέω",),
     "είπατε": ("λέω",),
     "είπαν": ("λέω",),
     "είπανε": ("λέω",),
     "πει": ("λέω"),
     "πω": ("λέω"),
     "πάω": ("πηγαίνω",),
     "πάς": ("πηγαίνω",),
     "πας": ("πηγαίνω",),
     "πάει": ("πηγαίνω",),
     "πάμε": ("πηγαίνω",),
     "πάτε": ("πηγαίνω",),
     "πάνε": ("πηγαίνω",),
     "πήγα": ("πηγαίνω",),
     "πήγες": ("πηγαίνω",),
     "πήγε": ("πηγαίνω",),
     "πήγαμε": ("πηγαίνω",),
     "πήγατε": ("πηγαίνω",),
     "πήγαν": ("πηγαίνω",),
     "πήγανε": ("πηγαίνω",),
     "έπαιζα": ("παίζω",),
     "έπαιζες": ("παίζω",),
     "έπαιζε": ("παίζω",),
     "έπαιζαν": ("παίζω,",),
     "έπαιξα": ("παίζω",),
     "έπαιξες": ("παίζω",),
     "έπαιξε": ("παίζω",),
     "έτρωγα": ("τρώω",),
     "έτρωγες": ("τρώω",),
     "έτρωγε": ("τρώω",),
     "έτρωγαν": ("τρώω",),
     "είχα": ("έχω",),
     "είχες": ("έχω",),
     "είχε": ("έχω",),
     "είχαμε": ("έχω",),
     "είχατε": ("έχω",),
     "είχαν": ("έχω",),
     "είχανε": ("έχω",),
     "έπαιρνα": ("παίρνω",),
     "έπαιρνες": ("παίρνω",),
     "έπαιρνε": ("παίρνω",),
     "έπαιρναν": ("παίρνω",),
     "εδίνα": ("δίνω",),
     "εδίνες": ("δίνω",),
     "εδίνε": ("δίνω",),
     "εδίναν": ("δίνω",),
     "έκανα": ("κάνω",),
     "έκανες": ("κάνω",),
     "έκανε": ("κάνω",),
     "έκαναν": ("κάνω",),
     "ήθελα": ("θέλω",),
     "ήθελες": ("θέλω",),
     "ήθελε": ("θέλω",),
     "ήθελαν": ("θέλω",),
     "έβλεπα": ("βλέπω",),
     "έβλεπες": ("βλέπω",),
     "έβλεπε": ("βλέπω",),
     "έβλεπαν": ("βλέπω",),
     "είδα": ("βλέπω",),
     "είδες": ("βλέπω",),
     "είδε": ("βλέπω",),
     "είδαμε": ("βλέπω",),
     "είδατε": ("βλέπω",),
     "είδαν": ("βλέπω",),
     "έφερνα": ("φέρνω",),
     "έφερνες": ("φέρνω",),
     "έφερνε": ("φέρνω",),
     "έφερναν": ("φέρνω",),
     "έφερα": ("φέρω",),
     "έφερες": ("φέρω",),
     "έφερε": ("φέρω",),
     "έφεραν": ("φέρω",),
     "έλαβα": ("λαμβάνω",),
     "έλαβες": ("λαμβάνω",),
     "έλαβε": ("λαμβάνω",),
     "έλαβαν": ("λαμβάνω",),
     "έβρισκα": ("βρίσκω",),
     "έβρισκες": ("βρίσκω",),
     "έβρισκε": ("βρίσκω",),
     "έβρισκαν": ("βρίσκω",),
     "ήξερα": ("ξέρω",),
     "ήξερες": ("ξέρω",),
     "ήξερε": ("ξέρω",),
     "ήξεραν": ("ξέρω",),
     "ανέφερα": ("αναφέρω",),
     "ανέφερες": ("αναφέρω",),
     "ανέφερε": ("αναφέρω",),
     "ανέφεραν": ("αναφέρω",),
     "έβαζα": ("βάζω",),
     "έβαζες": ("βάζω",),
     "έβαζε": ("βάζω",),
     "έβαζαν": ("βάζω",),
     "έμεινα": ("μένω",),
     "έμεινες": ("μένω",),
     "έμεινε": ("μένω",),
     "έμειναν": ("μένω",),
     "έβγαζα": ("βγάζω",),
     "έβγαζες": ("βγάζω",),
     "έβγαζε": ("βγάζω",),
     "έβγαζαν": ("βγάζω",),
     "έμπαινα": ("μπαίνω",),
     "έμπαινες": ("μπαίνω",),
     "έμπαινε": ("μπαίνω",),
     "έμπαιναν": ("μπαίνω",),
     "βγήκα": ("βγαίνω",),
     "βγήκες": ("βγαίνω",),
     "βγήκε": ("βγαίνω",),
     "βγήκαμε": ("βγαίνω",),
     "βγήκατε": ("βγαίνω",),
     "βγήκαν": ("βγαίνω",),
     "έπεφτα": ("πέφτω",),
     "έπεφτες": ("πέφτω",),
     "έπεφτε": ("πέφτω",),
     "έπεφταν": ("πέφτω",),
     "έπεσα": ("πέφτω",),
     "έπεσες": ("πέφτω",),
     "έπεσε": ("πέφτω",),
     "έπεσαν": ("πέφτω",),
     "έστειλα": ("στέλνω",),
     "έστειλες": ("στέλνω",),
     "έστειλε": ("στέλνω",),
     "έστειλαν": ("στέλνω",),
     "έφυγα": ("φεύγω",),
     "έφυγες": ("φεύγω",),
     "έφυγες": ("φεύγω",),
     "έφυγαν": ("φεύγω",),
     "έμαθα": ("μαθαίνω",),
     "έμαθες": ("μαθαίνω",),
     "έμαθε": ("μαθαίνω",),
     "έμαθαν": ("μαθαίνω",),
     "υπέβαλλα": ("υποβάλλω",),
     "υπέβαλλες": ("υποβάλλω",),
     "υπέβαλλε": ("υποβάλλω",),
     "υπέβαλλαν": ("υποβάλλω",),
     "έπινα": ("πίνω",),
     "έπινες": ("πίνω",),
     "έπινε": ("πίνω",),
     "έπιναν": ("πίνω",),
     "ήπια": ("πίνω",),
     "ήπιες": ("πίνω",),
     "ήπιε": ("πίνω",),
     "ήπιαμε": ("πίνω",),
     "ήπιατε": ("πίνω",),
     "ήπιαν": ("πίνω",),
     "ετύχα": ("τυχαίνω",),
     "ετύχες": ("τυχαίνω",),
     "ετύχε": ("τυχαίνω",),
     "ετύχαν": ("τυχαίνω",),
     "φάω": ("τρώω",),
     "φάς": ("τρώω",),
     "φάει": ("τρώω",),
     "φάμε": ("τρώω",),
     "φάτε": ("τρώω",),
     "φάνε": ("τρώω",),
     "φάν": ("τρώω",),
     "έτρωγα": ("τρώω",),
     "έτρωγες": ("τρώω",),
     "τρώγαμε": ("τρώω",),
     "τρώγατε": ("τρώω",),
     "τρώγανε": ("τρώω",),
     "τρώγαν": ("τρώω",),
     "πέρασα": ("περνώ",),
     "πέρασες": ("περνώ",),
     "πέρασε": ("περνώ",),
     "πέρασαμε": ("περνώ",),
     "πέρασατε": ("περνώ",),
     "πέρασαν": ("περνώ",),
     "έγδαρα": ("γδάρω",),
     "έγδαρες": ("γδάρω",),
     "έγδαρε": ("γδάρω",),
     "έγδαραν": ("γδάρω",),
     "έβγαλα": ("βγάλω",),
     "έβγαλες": ("βγάλω",),
     "έβγαλε": ("βγάλω",),
     "έβγαλαν": ("βγάλω",),
     "έφθασα": ("φτάνω",),
     "έφθασες": ("φτάνω",),
     "έφθασε": ("φτάνω",),
     "έφθασαν": ("φτάνω",),

}



# -*- coding: utf-8 -*-

from __future__ import unicode_literals

from ...symbols import ORTH, LEMMA, NORM

_exc = {}

for token in ["Απ'", "ΑΠ'", "αφ'", "Αφ'"]:
    _exc[token] = [
        {ORTH: token, LEMMA: "από", NORM: "από"}
    ]

for token in ["Αλλ'", "αλλ'"]:
    _exc[token] = [
        {ORTH: token, LEMMA: "αλλά", NORM: "αλλά"}
    ]

for token in ["παρ'", "Παρ'", "ΠΑΡ'"]:
    _exc[token] = [
        {ORTH: token, LEMMA: "παρά", NORM: "παρά"}
    ]

for token in ["καθ'", "Καθ'"]:
    _exc[token] = [
        {ORTH: token, LEMMA: "κάθε", NORM: "κάθε"}
    ]

for token in ["κατ'", "Κατ'"]:
    _exc[token] = [
        {ORTH: token, LEMMA: "κατά", NORM: "κατά"}
    ]

for token in ["'ΣΟΥΝ", "'ναι", "'ταν", "'τανε", "'μαστε", "'μουνα", "'μουν"]:
    _exc[token] = [
        {ORTH: token, LEMMA: "είμαι", NORM: "είμαι"}
    ]

for token in ["Επ'", "επ'", "εφ'", "Εφ'"]:
    _exc[token] = [
        {ORTH: token, LEMMA: "επί", NORM: "επί"}
    ]

for token in ["Δι'", "δι'"]:
    _exc[token] = [
        {ORTH: token, LEMMA: "δια", NORM: "δια"}
    ]

for token in ["'χουν", "'χουμε", "'χαμε", "'χα", "'χε", "'χεις", "'χει"]:
    _exc[token] = [
        {ORTH: token, LEMMA: "έχω", NORM: "έχω"}
    ]

for token in ["υπ'", "Υπ'"]:
    _exc[token] = [
        {ORTH: token, LEMMA: "υπό", NORM: "υπό"}
    ]

for token in ["Μετ'", "ΜΕΤ'", "'μετ"]:
    _exc[token] = [
        {ORTH: token, LEMMA: "μετά", NORM: "μετά"}
    ]

for token in ["Μ'", "μ'"]:
    _exc[token] = [
        {ORTH: token, LEMMA: "με", NORM: "με"}
    ]

for token in ["Γι'", "ΓΙ'", "γι'"]:
    _exc[token] = [
        {ORTH: token, LEMMA: "για", NORM: "για"}
    ]

for token in ["Σ'", "σ'"]:
    _exc[token] = [
        {ORTH: token, LEMMA: "σε", NORM: "σε"}
    ]

for token in ["Θ'", "θ'"]:
    _exc[token] = [
        {ORTH: token, LEMMA: "θα", NORM: "θα"}
    ]

for token in ["Ν'", "ν'"]:
    _exc[token] = [
        {ORTH: token, LEMMA: "να", NORM: "να"}
    ]

for token in ["Τ'", "τ'"]:
    _exc[token] = [
        {ORTH: token, LEMMA: "να", NORM: "να"}
    ]

for token in ["'γω", "'σένα", "'μεις"]:
    _exc[token] = [
        {ORTH: token, LEMMA: "εγώ", NORM: "εγώ"}
    ]

for token in ["Τ'", "τ'"]:
    _exc[token] = [
        {ORTH: token, LEMMA: "το", NORM: "το"}
    ]

for token in ["Φέρ'", "Φερ'", "φέρ'", "φερ'"]:
    _exc[token] = [
        {ORTH: token, LEMMA: "φέρνω", NORM: "φέρνω"}
    ]

for token in ["'ρθούνε", "'ρθουν", "'ρθει", "'ρθεί", "'ρθε", "'ρχεται"]:
    _exc[token] = [
        {ORTH: token, LEMMA: "έρχομαι", NORM: "έρχομαι"}
    ]

for token in ["'πανε", "'λεγε", "'λεγαν", "'πε", "'λεγα"]:
    _exc[token] = [
        {ORTH: token, LEMMA: "λέγω", NORM: "λέγω"}
    ]

for token in ["Πάρ'", "πάρ'"]:
    _exc[token] = [
        {ORTH: token, LEMMA: "παίρνω", NORM: "παίρνω"}
    ]

for token in ["μέσ'", "Μέσ'", "μεσ'"]:
    _exc[token] = [
        {ORTH: token, LEMMA: "μέσα", NORM: "μέσα"}
    ]

for token in ["Δέσ'", "Δεσ'", "δεσ'"]:
    _exc[token] = [
        {ORTH: token, LEMMA: "δένω", NORM: "δένω"}
    ]

for token in ["'κανε", "Κάν'"]:
    _exc[token] = [
        {ORTH: token, LEMMA: "κάνω", NORM: "κάνω"}
    ]

_other_exc = {

    "κι": [
        {ORTH: "κι", LEMMA: "και", NORM: "και"},
    ],

    "Παίξ'": [
        {ORTH: "Παίξ'", LEMMA: "παίζω", NORM: "παίζω"},
    ],

    "Αντ'": [
        {ORTH: "Αντ'", LEMMA: "αντί", NORM: "αντί"},
    ],

    "ολ'": [
        {ORTH: "ολ'", LEMMA: "όλος", NORM: "όλος"},
    ],

    "ύστερ'": [
        {ORTH: "ύστερ'", LEMMA: "ύστερα", NORM: "ύστερα"},
    ],

    "'πρεπε": [
        {ORTH: "'πρεπε", LEMMA: "πρέπει", NORM: "πρέπει"},
    ],

    "Δύσκολ'": [
        {ORTH: "Δύσκολ'", LEMMA: "δύσκολος", NORM: "δύσκολος"},
    ],

    "'θελα": [
        {ORTH: "'θελα", LEMMA: "θέλω", NORM: "θέλω"},
    ],

    "'γραφα": [
        {ORTH: "'γραφα", LEMMA: "γράφω", NORM: "γράφω"},
    ],

    "'παιρνα": [
        {ORTH: "'παιρνα", LEMMA: "παίρνω", NORM: "παίρνω"},
    ],

    "'δειξε": [
        {ORTH: "'δειξε", LEMMA: "δείχνω", NORM: "δείχνω"},
    ],

    "όμουρφ'": [
        {ORTH: "όμουρφ'", LEMMA: "όμορφος", NORM: "όμορφος"},
    ],

    "κ'τσή": [
        {ORTH: "κ'τσή", LEMMA: "κουτσός", NORM: "κουτσός"},
    ],

    "μηδ'": [
        {ORTH: "μηδ'", LEMMA: "μήδε", NORM: "μήδε"},
    ],

    "'ξομολογήθηκε": [
        {ORTH: "'ξομολογήθηκε", LEMMA: "εξομολογούμαι", NORM: "εξομολογούμαι"},
    ],

    "'μας": [
        {ORTH: "'μας", LEMMA: "εμάς", NORM: "εμάς"},
    ],

    "'ξερες": [
        {ORTH: "'ξερες", LEMMA: "ξέρω", NORM: "ξέρω"},
    ],

    "έφθασ'": [
        {ORTH: "έφθασ'", LEMMA: "φθάνω", NORM: "φθάνω"},
    ],

    "εξ'": [
        {ORTH: "εξ'", LEMMA: "εκ", NORM: "εκ"},
    ],

    "δώσ'": [
        {ORTH: "δώσ'", LEMMA: "δίνω", NORM: "δίνω"},
    ],

    "τίποτ'": [
        {ORTH: "τίποτ'", LEMMA: "τίποτα", NORM: "τίποτα"},
    ],

    "Λήξ'": [
        {ORTH: "Λήξ'", LEMMA: "λήγω", NORM: "λήγω"},
    ],

    "άσ'": [
        {ORTH: "άσ'", LEMMA: "αφήνω", NORM: "αφήνω"},
    ],

    "Στ'": [
        {ORTH: "Στ'", LEMMA: "στο", NORM: "στο"},

    ],

    "Δωσ'": [
        {ORTH: "Δωσ'", LEMMA: "δίνω", NORM: "δίνω"},
    ],

    "Βάψ'": [
        {ORTH: "Βάψ'", LEMMA: "βάφω", NORM: "βάφω"},
    ],

    "Αλλ'": [
        {ORTH: "Αλλ'", LEMMA: "αλλά", NORM: "αλλά"},
    ],

    "Αμ'": [
        {ORTH: "Αμ'", LEMMA: "άμα", NORM: "άμα"},
    ],

    "Αγόρασ'": [
        {ORTH: "Αγόρασ'", LEMMA: "αγοράζω", NORM: "αγοράζω"},
    ],

    "'φύγε": [
        {ORTH: "'φύγε", LEMMA: "φεύγω", NORM: "φεύγω"},
    ],

    "'φερε": [
        {ORTH: "'φερε", LEMMA: "φέρνω", NORM: "φέρνω"},
    ],

    "'φαγε": [
        {ORTH: "'φαγε", LEMMA: "τρώω", NORM: "τρώω"},
    ],

    "'σπαγαν": [
        {ORTH: "'σπαγαν", LEMMA: "σπάω", NORM: "σπάω"},
    ],

    "'σκασε": [
        {ORTH: "'σκασε", LEMMA: "σκάω", NORM: "σκάω"},
    ],

    "'σβηνε": [
        {ORTH: "'σβηνε", LEMMA: "σβήνω", NORM: "σβήνω"},
    ],

    "'ριξε": [
        {ORTH: "'ριξε", LEMMA: "ρίχνω", NORM: "ρίχνω"},
    ],

    "'κλεβε": [
        {ORTH: "'κλεβε", LEMMA: "κλέβω", NORM: "κλέβω"},
    ],

    "'κει": [
        {ORTH: "'κει", LEMMA: "εκεί", NORM: "εκεί"},
    ],

    "'βλεπε": [
        {ORTH: "'βλεπε", LEMMA: "βλέπω", NORM: "βλέπω"},
    ],

    "'βγαινε": [
        {ORTH: "'βγαινε", LEMMA: "βγαίνω", NORM: "βγαίνω"},
    ]
}

_exc.update(_other_exc)

for h in range(1, 12 + 1):

    for period in ["π.μ.", "πμ"]:
        _exc["%d%s" % (h, period)] = [
            {ORTH: "%d" % h},
            {ORTH: period, LEMMA: "π.μ.", NORM: "π.μ."}]

    for period in ["μ.μ.", "μμ"]:
        _exc["%d%s" % (h, period)] = [
            {ORTH: "%d" % h},
            {ORTH: period, LEMMA: "μ.μ.", NORM: "μ.μ."}]

for exc_data in [
    {ORTH: "ΑΓΡ.", LEMMA: "Αγροτικός", NORM: "Αγροτικός"},
    {ORTH: "Αγ. Γρ.", LEMMA: "Αγία Γραφή", NORM: "Αγία Γραφή"},
    {ORTH: "Αθ.", LEMMA: "Αθανάσιος", NORM: "Αθανάσιος"},
    {ORTH: "Αλεξ.", LEMMA: "Αλέξανδρος", NORM: "Αλέξανδρος"},
    {ORTH: "Απρ.", LEMMA: "Απρίλιος", NORM: "Απρίλιος"},
    {ORTH: "Αύγ.", LEMMA: "Αύγουστος", NORM: "Αύγουστος"},
    {ORTH: "Δεκ.", LEMMA: "Δεκέμβριος", NORM: "Δεκέμβριος"},
    {ORTH: "Δημ.", LEMMA: "Δήμος", NORM: "Δήμος"},
    {ORTH: "Ιαν.", LEMMA: "Ιανουάριος", NORM: "Ιανουάριος"},
    {ORTH: "Ιούλ.", LEMMA: "Ιούλιος", NORM: "Ιούλιος"},
    {ORTH: "Ιούν.", LEMMA: "Ιούνιος", NORM: "Ιούνιος"},
    {ORTH: "Ιωαν.", LEMMA: "Ιωάννης", NORM: "Ιωάννης"},
    {ORTH: "Μ. Ασία", LEMMA: "Μικρά Ασία", NORM: "Μικρά Ασία"},
    {ORTH: "Μάρτ.", LEMMA: "Μάρτιος", NORM: "Μάρτιος"},
    {ORTH: "Μάρτ'", LEMMA: "Μάρτιος", NORM: "Μάρτιος"},
    {ORTH: "Νοέμβρ.", LEMMA: "Νοέμβριος", NORM: "Νοέμβριος"},
    {ORTH: "Οκτ.", LEMMA: "Οκτώβριος", NORM: "Οκτώβριος"},
    {ORTH: "Σεπτ.", LEMMA: "Σεπτέμβριος", NORM: "Σεπτέμβριος"},
    {ORTH: "Φεβρ.", LEMMA: "Φεβρουάριος", NORM: "Φεβρουάριος"},
]:
    _exc[exc_data[ORTH]] = [exc_data]

for orth in [
    "$ΗΠΑ",
    "Α'", "Α.Ε.", "Α.Ε.Β.Ε.", "Α.Ε.Ι.", "Α.Ε.Π.", "Α.Μ.Α.", "Α.Π.Θ.", "Α.Τ.", "Α.Χ.", "ΑΝ.", "Αγ.", "Αλ.", "Αν.",
    "Αντ.", "Απ.",
    "Β'", "Β)", "Β.Ζ.", "Β.Ι.Ο.", "Β.Κ.", "Β.Μ.Α.", "Βασ.",
    "Γ'", "Γ)", "Γ.Γ.", "Γ.Δ.", "Γκ.",
    "Δ.Ε.Η.", "Δ.Ε.Σ.Ε.", "Δ.Ν.", "Δ.Ο.Υ.", "Δ.Σ.", "Δ.Υ.", "ΔΙ.ΚΑ.Τ.Σ.Α.", "Δηλ.", "Διον.",
    "Ε.Α.", "Ε.Α.Κ.", "Ε.Α.Π.", "Ε.Ε.", "Ε.Κ.", "Ε.ΚΕ.ΠΙΣ.", "Ε.Λ.Α.", "Ε.Λ.Ι.Α.", "Ε.Π.Σ.", "Ε.Π.Τ.Α.", "Ε.Σ.Ε.Ε.Κ.",
    "Ε.Υ.Κ.", "ΕΕ.", "ΕΚ.", "ΕΛ.", "ΕΛ.ΑΣ.", "Εθν.", "Ελ.", "Εμ.", "Επ.", "Ευ.",
    "Η'", "Η.Π.Α.",
    "ΘΕ.", "Θεμ.", "Θεοδ.", "Θρ.",
    "Ι.Ε.Κ.", "Ι.Κ.Α.", "Ι.Κ.Υ.", "Ι.Σ.Θ.", "Ι.Χ.", "ΙΖ'", "ΙΧ.",
    "Κ.Α.Α.", "Κ.Α.Ε.", "Κ.Β.Σ.", "Κ.Δ.", "Κ.Ε.", "Κ.Ε.Κ.", "Κ.Ι.", "Κ.Κ.", "Κ.Ι.Θ.", "Κ.Ι.Θ.", "Κ.ΚΕΚ.", "Κ.Ο.",
    "Κ.Π.Ρ.", "ΚΑΤ.", "ΚΚ.", "Καν.", "Καρ.", "Κατ.", "Κυρ.", "Κων.",
    "Λ.Α.", "Λ.χ.", "Λ.Χ.", "Λεωφ.", "Λι.",
    "Μ.Δ.Ε.", "Μ.Ε.Ο.", "Μ.Ζ.", "Μ.Μ.Ε.", "Μ.Ο.", "Μεγ.", "Μιλτ.", "Μιχ.",
    "Ν.Δ.", "Ν.Ε.Α.", "Ν.Κ.", "Ν.Ο.", "Ν.Ο.Θ.", "Ν.Π.Δ.Δ.", "Ν.Υ.", "ΝΔ.", "Νικ.", "Ντ'", "Ντ.",
    "Ο'", "Ο.Α.", "Ο.Α.Ε.Δ.", "Ο.Δ.", "Ο.Ε.Ε.", "Ο.Ε.Ε.Κ.", "Ο.Η.Ε.", "Ο.Κ.",
    "Π.Δ.", "Π.Ε.Κ.Δ.Υ.", "Π.Ε.Π.", "Π.Μ.Σ.", "ΠΟΛ.", "Π.Χ.", "Παρ.", "Πλ.", "Πρ.",
    "Σ.Δ.Ο.Ε.", "Σ.Ε.", "Σ.Ε.Κ.", "Σ.Π.Δ.Ω.Β.", "Σ.Τ.", "Σαβ.", "Στ.", "ΣτΕ.", "Στρ.",
    "Τ.Α.", "Τ.Ε.Ε.", "Τ.Ε.Ι.", "ΤΡ.", "Τζ.", "Τηλ.",
    "Υ.Γ.", "ΥΓ.", "ΥΠ.Ε.Π.Θ.",
    "Φ.Α.Β.Ε.", "Φ.Κ.", "Φ.Σ.", "Φ.Χ.", "Φ.Π.Α.", "Φιλ.",
    "Χ.Α.Α.", "ΧΡ.", "Χ.Χ.", "Χαρ.", "Χιλ.", "Χρ.",
    "άγ.", "άρθρ.", "αι.", "αν.", "απ.", "αρ.", "αριθ.", "αριθμ.",
    "β'", "βλ.",
    "γ.γ.", "γεν.", "γραμμ.",
    "δ.δ.", "δ.σ.", "δηλ.", "δισ.", "δολ.", "δρχ.",
    "εκ.", "εκατ.", "ελ.",
    "θιν'",
    "κ.", "κ.ά.", "κ.α.", "κ.κ.", "κ.λπ.", "κ.ο.κ.", "κ.τ.λ.", "κλπ.", "κτλ.", "κυβ.",
    "λ.χ.",
    "μ.", "μ.Χ.", "μ.μ.", "μιλ.",
    "ντ'",
    "π.Χ.", "π.β.", "π.δ.", "π.μ.", "π.χ.",
    "σ.", "σ.α.λ.", "σ.σ.", "σελ.", "στρ.",
    "τ'ς", "τ.μ.", "τετ.", "τετρ.", "τηλ.", "τρισ.", "τόν.",
    "υπ.",
    "χ.μ.", "χγρ.", "χιλ.", "χλμ."
]:
    _exc[orth] = [{ORTH: orth}]

TOKENIZER_EXCEPTIONS = _exc



# coding: utf8
from __future__ import unicode_literals

from .tokenizer_exceptions import TOKENIZER_EXCEPTIONS
from .norm_exceptions import NORM_EXCEPTIONS
from .punctuation import TOKENIZER_INFIXES
from .tag_map import TAG_MAP
from .stop_words import STOP_WORDS
from .lemmatizer import LOOKUP
from .syntax_iterators import SYNTAX_ITERATORS

from ..tokenizer_exceptions import BASE_EXCEPTIONS
from ..norm_exceptions import BASE_NORMS
from ...language import Language
from ...attrs import LANG, NORM
from ...util import update_exc, add_lookups


class GermanDefaults(Language.Defaults):
    lex_attr_getters = dict(Language.Defaults.lex_attr_getters)
    lex_attr_getters[LANG] = lambda text: 'de'
    lex_attr_getters[NORM] = add_lookups(Language.Defaults.lex_attr_getters[NORM],
                                         NORM_EXCEPTIONS, BASE_NORMS)
    tokenizer_exceptions = update_exc(BASE_EXCEPTIONS, TOKENIZER_EXCEPTIONS)
    infixes = TOKENIZER_INFIXES
    tag_map = TAG_MAP
    stop_words = STOP_WORDS
    syntax_iterators = SYNTAX_ITERATORS
    lemma_lookup = LOOKUP


class German(Language):
    lang = 'de'
    Defaults = GermanDefaults


__all__ = ['German']



# encoding: utf8
from __future__ import unicode_literals

# Tatar stopwords are from https://github.com/aliiae/stopwords-tt

STOP_WORDS = set("""алай алайса алар аларга аларда алардан аларны аларның аларча
алары аларын аларынга аларында аларыннан аларының алтмыш алтмышынчы алтмышынчыга
алтмышынчыда алтмышынчыдан алтмышынчылар алтмышынчыларга алтмышынчыларда
алтмышынчылардан алтмышынчыларны алтмышынчыларның алтмышынчыны алтмышынчының
алты алтылап алтынчы алтынчыга алтынчыда алтынчыдан алтынчылар алтынчыларга
алтынчыларда алтынчылардан алтынчыларны алтынчыларның алтынчыны алтынчының
алтышар анда андагы андай андый андыйга андыйда андыйдан андыйны андыйның аннан
ансы анча аны аныкы аныкын аныкынга аныкында аныкыннан аныкының анысы анысын
анысынга анысында анысыннан анысының аның аныңча аркылы ары аша аңа аңар аңарга
аңарда аңардагы аңардан

бар бара барлык барча барчасы барчасын барчасына барчасында барчасыннан
барчасының бары башка башкача бе­лән без безгә бездә бездән безне безнең безнеңчә
белдерүенчә белән бер бергә беренче беренчегә беренчедә беренчедән беренчеләр
беренчеләргә беренчеләрдә беренчеләрдән беренчеләрне беренчеләрнең беренчене
беренченең беркайда беркайсы беркая беркаян беркем беркемгә беркемдә беркемне
беркемнең беркемнән берлән берни бернигә бернидә бернидән бернинди бернине
бернинең берничек берничә бернәрсә бернәрсәгә бернәрсәдә бернәрсәдән бернәрсәне
бернәрсәнең беррәттән берсе берсен берсенгә берсендә берсенең берсеннән берәр
берәрсе берәрсен берәрсендә берәрсенең берәрсеннән берәрсенә берәү бигрәк бик
бирле бит биш бишенче бишенчегә бишенчедә бишенчедән бишенчеләр бишенчеләргә
бишенчеләрдә бишенчеләрдән бишенчеләрне бишенчеләрнең бишенчене бишенченең
бишләп болай болар боларга боларда болардан боларны боларның болары боларын
боларынга боларында боларыннан боларының бу буе буена буенда буенча буйлап
буларак булачак булды булмый булса булып булыр булырга бусы бүтән бәлки бән
бәрабәренә бөтен бөтенесе бөтенесен бөтенесендә бөтенесенең бөтенесеннән
бөтенесенә

вә

гел генә гына гүя гүяки гәрчә

да ди дигән диде дип дистәләгән дистәләрчә дүрт дүртенче дүртенчегә дүртенчедә
дүртенчедән дүртенчеләр дүртенчеләргә дүртенчеләрдә дүртенчеләрдән дүртенчеләрне
дүртенчеләрнең дүртенчене дүртенченең дүртләп дә

егерме егерменче егерменчегә егерменчедә егерменчедән егерменчеләр
егерменчеләргә егерменчеләрдә егерменчеләрдән егерменчеләрне егерменчеләрнең
егерменчене егерменченең ел елда

иде идек идем ике икенче икенчегә икенчедә икенчедән икенчеләр икенчеләргә
икенчеләрдә икенчеләрдән икенчеләрне икенчеләрнең икенчене икенченең икешәр икән
илле илленче илленчегә илленчедә илленчедән илленчеләр илленчеләргә
илленчеләрдә илленчеләрдән илленчеләрне илленчеләрнең илленчене илленченең илә
илән инде исә итеп иткән итте итү итә итәргә иң

йөз йөзенче йөзенчегә йөзенчедә йөзенчедән йөзенчеләр йөзенчеләргә йөзенчеләрдә
йөзенчеләрдән йөзенчеләрне йөзенчеләрнең йөзенчене йөзенченең йөзләгән йөзләрчә
йөзәрләгән

кадәр кай кайбер кайберләре кайберсе кайберәү кайберәүгә кайберәүдә кайберәүдән
кайберәүне кайберәүнең кайдагы кайсы кайсыбер кайсын кайсына кайсында кайсыннан
кайсының кайчангы кайчандагы кайчаннан караганда карамастан карамый карата каршы
каршына каршында каршындагы кебек кем кемгә кемдә кемне кемнең кемнән кенә ки
килеп килә кирәк кына кырыгынчы кырыгынчыга кырыгынчыда кырыгынчыдан
кырыгынчылар кырыгынчыларга кырыгынчыларда кырыгынчылардан кырыгынчыларны
кырыгынчыларның кырыгынчыны кырыгынчының кырык күк күпләгән күпме күпмеләп
күпмешәр күпмешәрләп күптән күрә

ләкин

максатында менә мең меңенче меңенчегә меңенчедә меңенчедән меңенчеләр
меңенчеләргә меңенчеләрдә меңенчеләрдән меңенчеләрне меңенчеләрнең меңенчене
меңенченең меңләгән меңләп меңнәрчә меңәрләгән меңәрләп миллиард миллиардлаган
миллиардларча миллион миллионлаган миллионнарча миллионынчы миллионынчыга
миллионынчыда миллионынчыдан миллионынчылар миллионынчыларга миллионынчыларда
миллионынчылардан миллионынчыларны миллионынчыларның миллионынчыны
миллионынчының мин миндә мине минем минемчә миннән миңа монда мондагы мондые
мондыен мондыенгә мондыендә мондыеннән мондыеның мондый мондыйга мондыйда
мондыйдан мондыйлар мондыйларга мондыйларда мондыйлардан мондыйларны
мондыйларның мондыйлары мондыйларын мондыйларынга мондыйларында мондыйларыннан
мондыйларының мондыйны мондыйның моннан монсыз монча моны моныкы моныкын
моныкынга моныкында моныкыннан моныкының монысы монысын монысынга монысында
монысыннан монысының моның моңа моңар моңарга мәгълүматынча мәгәр мән мөмкин

ни нибарысы никадәре нинди ниндие ниндиен ниндиенгә ниндиендә ниндиенең
ниндиеннән ниндиләр ниндиләргә ниндиләрдә ниндиләрдән ниндиләрен ниндиләренн
ниндиләреннгә ниндиләренндә ниндиләреннең ниндиләренннән ниндиләрне ниндиләрнең
ниндирәк нихәтле ничаклы ничек ничәшәр ничәшәрләп нуль нче нчы нәрсә нәрсәгә 
нәрсәдә нәрсәдән нәрсәне нәрсәнең

саен сез сезгә сездә сездән сезне сезнең сезнеңчә сигез сигезенче сигезенчегә
сигезенчедә сигезенчедән сигезенчеләр сигезенчеләргә сигезенчеләрдә
сигезенчеләрдән сигезенчеләрне сигезенчеләрнең сигезенчене сигезенченең
сиксән син синдә сине синең синеңчә синнән сиңа соң сыман сүзенчә сүзләренчә

та таба теге тегеләй тегеләр тегеләргә тегеләрдә тегеләрдән тегеләре тегеләрен
тегеләренгә тегеләрендә тегеләренең тегеләреннән тегеләрне тегеләрнең тегенди 
тегендигә тегендидә тегендидән тегендине тегендинең тегендә тегендәге тегене
тегенеке тегенекен тегенекенгә тегенекендә тегенекенең тегенекеннән тегенең
тегеннән тегесе тегесен тегесенгә тегесендә тегесенең тегесеннән тегеңә тиеш тик
тикле тора триллиард триллион тугыз тугызлап тугызлашып тугызынчы тугызынчыга
тугызынчыда тугызынчыдан тугызынчылар тугызынчыларга тугызынчыларда
тугызынчылардан тугызынчыларны тугызынчыларның тугызынчыны тугызынчының туксан
туксанынчы туксанынчыга туксанынчыда туксанынчыдан туксанынчылар туксанынчыларга
туксанынчыларда туксанынчылардан туксанынчыларны туксанынчыларның туксанынчыны
туксанынчының турында тыш түгел тә тәгаенләнгән төмән

уенча уйлавынча ук ул ун уналты уналтынчы уналтынчыга уналтынчыда уналтынчыдан
уналтынчылар уналтынчыларга уналтынчыларда уналтынчылардан уналтынчыларны
уналтынчыларның уналтынчыны уналтынчының унарлаган унарлап унаула унаулап унбер
унберенче унберенчегә унберенчедә унберенчедән унберенчеләр унберенчеләргә
унберенчеләрдә унберенчеләрдән унберенчеләрне унберенчеләрнең унберенчене
унберенченең унбиш унбишенче унбишенчегә унбишенчедә унбишенчедән унбишенчеләр
унбишенчеләргә унбишенчеләрдә унбишенчеләрдән унбишенчеләрне унбишенчеләрнең
унбишенчене унбишенченең ундүрт ундүртенче ундүртенчегә ундүртенчедә
ундүртенчедән ундүртенчеләр ундүртенчеләргә ундүртенчеләрдә ундүртенчеләрдән
ундүртенчеләрне ундүртенчеләрнең ундүртенчене ундүртенченең унике уникенче
уникенчегә уникенчедә уникенчедән уникенчеләр уникенчеләргә уникенчеләрдә
уникенчеләрдән уникенчеләрне уникенчеләрнең уникенчене уникенченең унлаган
унлап уннарча унсигез унсигезенче унсигезенчегә унсигезенчедә унсигезенчедән
унсигезенчеләр унсигезенчеләргә унсигезенчеләрдә унсигезенчеләрдән
унсигезенчеләрне унсигезенчеләрнең унсигезенчене унсигезенченең унтугыз
унтугызынчы унтугызынчыга унтугызынчыда унтугызынчыдан унтугызынчылар
унтугызынчыларга унтугызынчыларда унтугызынчылардан унтугызынчыларны
унтугызынчыларның унтугызынчыны унтугызынчының унынчы унынчыга унынчыда
унынчыдан унынчылар унынчыларга унынчыларда унынчылардан унынчыларны
унынчыларның унынчыны унынчының унҗиде унҗиденче унҗиденчегә унҗиденчедә
унҗиденчедән унҗиденчеләр унҗиденчеләргә унҗиденчеләрдә унҗиденчеләрдән
унҗиденчеләрне унҗиденчеләрнең унҗиденчене унҗиденченең унөч унөченче унөченчегә
унөченчедә унөченчедән унөченчеләр унөченчеләргә унөченчеләрдә унөченчеләрдән
унөченчеләрне унөченчеләрнең унөченчене унөченченең утыз утызынчы утызынчыга
утызынчыда утызынчыдан утызынчылар утызынчыларга утызынчыларда утызынчылардан
утызынчыларны утызынчыларның утызынчыны утызынчының

фикеренчә фәкать

хакында хәбәр хәлбуки хәтле хәтта

чаклы чакта чөнки

шикелле шул шулай шулар шуларга шуларда шулардан шуларны шуларның шулары шуларын
шуларынга шуларында шуларыннан шуларының шулкадәр шултикле шултиклем шулхәтле
шулчаклы шунда шундагы шундый шундыйга шундыйда шундыйдан шундыйны шундыйның
шунлыктан шуннан шунсы шунча шуны шуныкы шуныкын шуныкынга шуныкында шуныкыннан
шуныкының шунысы шунысын шунысынга шунысында шунысыннан шунысының шуның шушы
шушында шушыннан шушыны шушының шушыңа шуңа шуңар шуңарга

элек

югыйсә юк юкса

я ягъни язуынча яисә яки яктан якын ярашлы яхут яшь яшьлек

җиде җиделәп җиденче җиденчегә җиденчедә җиденчедән җиденчеләр җиденчеләргә
җиденчеләрдә җиденчеләрдән җиденчеләрне җиденчеләрнең җиденчене җиденченең
җидешәр җитмеш җитмешенче җитмешенчегә җитмешенчедә җитмешенчедән җитмешенчеләр
җитмешенчеләргә җитмешенчеләрдә җитмешенчеләрдән җитмешенчеләрне
җитмешенчеләрнең җитмешенчене җитмешенченең җыенысы

үз үзе үзем үземдә үземне үземнең үземнән үземә үзен үзендә үзенең үзеннән үзенә
үк

һичбер һичбере һичберен һичберендә һичберенең һичбереннән һичберенә һичберсе
һичберсен һичберсендә һичберсенең һичберсеннән һичберсенә һичберәү һичберәүгә
һичберәүдә һичберәүдән һичберәүне һичберәүнең һичкайсы һичкайсыга һичкайсыда
һичкайсыдан һичкайсыны һичкайсының һичкем һичкемгә һичкемдә һичкемне һичкемнең
һичкемнән һични һичнигә һичнидә һичнидән һичнинди һичнине һичнинең һичнәрсә
һичнәрсәгә һичнәрсәдә һичнәрсәдән һичнәрсәне һичнәрсәнең һәм һәммә һәммәсе
һәммәсен һәммәсендә һәммәсенең һәммәсеннән һәммәсенә һәр һәрбер һәрбере һәрберсе
һәркайсы һәркайсыга һәркайсыда һәркайсыдан һәркайсыны һәркайсының һәркем
һәркемгә һәркемдә һәркемне һәркемнең һәркемнән һәрни һәрнәрсә һәрнәрсәгә
һәрнәрсәдә һәрнәрсәдән һәрнәрсәне һәрнәрсәнең һәртөрле

ә әгәр әйтүенчә әйтүләренчә әлбәттә әле әлеге әллә әмма әнә

өстәп өч өчен өченче өченчегә өченчедә өченчедән өченчеләр өченчеләргә
өченчеләрдә өченчеләрдән өченчеләрне өченчеләрнең өченчене өченченең өчләп
өчәрләп""".split())



from __future__ import unicode_literals

from ...symbols import POS, ADV, NOUN, ADP, PRON, SCONJ, PROPN, DET, SYM, INTJ
from ...symbols import PUNCT, NUM, AUX, X, ADJ, VERB, PART, SPACE, CCONJ


TAG_MAP = {
    "ADJ": {POS: ADJ},
    "ADV": {POS: ADV},
    "INTJ": {POS: INTJ},
    "NOUN": {POS: NOUN},
    "PROPN": {POS: PROPN},
    "VERB": {POS: VERB},
    "ADP": {POS: ADP},
    "CCONJ": {POS: CCONJ},
    "SCONJ": {POS: SCONJ},
    "PART": {POS: PART},
    "PUNCT": {POS: PUNCT},
    "SYM": {POS: SYM},
    "NUM": {POS: NUM},
    "PRON": {POS: PRON},
    "AUX": {POS: AUX},
    "SPACE": {POS: SPACE},
    "DET": {POS: DET},
    "X": {POS: X}
}



# coding: utf-8
from __future__ import unicode_literals

import pytest


# Note: "chromosomes" worked previous the bug fix
@pytest.mark.models('en')
@pytest.mark.parametrize('word,lemmas', [("chromosomes", ["chromosome"]), ("endosomes", ["endosome"]), ("colocalizes", ["colocaliz", "colocalize"])])
def test_issue781(EN, word, lemmas):
    lemmatizer = EN.Defaults.create_lemmatizer()
    assert sorted(lemmatizer(word, 'noun', morphology={'number': 'plur'})) == sorted(lemmas)



# encoding: utf8
from __future__ import unicode_literals


# Source: http://www.ranks.nl/stopwords/polish

STOP_WORDS = set("""
ach aj albo

bardzo bez bo być

ci cię ciebie co czy

daleko dla dlaczego dlatego do dobrze dokąd dość dużo dwa dwaj dwie dwoje dziś
dzisiaj

gdyby gdzie

go

ich ile im inny

ja ją jak jakby jaki je jeden jedna jedno jego jej jemu jeśli jest jestem
jeżeli już

każdy kiedy kierunku kto ku

lub

ma mają mam mi mną mnie moi mój moja moje może mu my

na nam nami nas nasi nasz nasza nasze natychmiast nią nic nich nie niego niej
niemu nigdy nim nimi niż

obok od około on ona one oni ono owszem

po pod ponieważ przed przedtem

są sam sama się skąd

tak taki tam ten to tobą tobie tu tutaj twoi twój twoja twoje ty

wam wami was wasi wasz wasza wasze we więc wszystko wtedy wy

żaden zawsze że
""".split())



# coding: utf-8
from __future__ import unicode_literals

from ...matcher import Matcher
from ...attrs import IS_PUNCT, ORTH

import pytest


def test_issue587(en_tokenizer):
    """Test that Matcher doesn't segfault on particular input"""
    doc = en_tokenizer('a b; c')
    matcher = Matcher(doc.vocab)
    matcher.add('TEST1', None, [{ORTH: 'a'}, {ORTH: 'b'}])
    matches = matcher(doc)
    assert len(matches) == 1
    matcher.add('TEST2', None, [{ORTH: 'a'}, {ORTH: 'b'}, {IS_PUNCT: True}, {ORTH: 'c'}])
    matches = matcher(doc)
    assert len(matches) == 2
    matcher.add('TEST3', None, [{ORTH: 'a'}, {ORTH: 'b'}, {IS_PUNCT: True}, {ORTH: 'd'}])
    matches = matcher(doc)
    assert len(matches) == 2



# coding: utf-8
from __future__ import unicode_literals

import pytest

LEMMAS = (
        ('新しく', '新しい'),
        ('赤く', '赤い'),
        ('すごく', '凄い'),
        ('いただきました', '頂く'),
        ('なった', '成る'))

@pytest.mark.parametrize('word,lemma', LEMMAS)
def test_japanese_lemmas(JA, word, lemma):
    test_lemma = JA(word)[0].lemma_
    assert test_lemma == lemma





# coding: utf8
from __future__ import unicode_literals


"""
Example sentences to test spaCy and its language models.

>>> from spacy.lang.it.examples import sentences
>>> docs = nlp.pipe(sentences)
"""


sentences = [
    "Apple vuole comprare una startup del Regno Unito per un miliardo di dollari",
    "Le automobili a guida autonoma spostano la responsabilità assicurativa verso i produttori",
    "San Francisco prevede di bandire i robot di consegna porta a porta",
    "Londra è una grande città del Regno Unito."
]



# coding: utf8
from __future__ import unicode_literals

from ..punctuation import TOKENIZER_PREFIXES as BASE_TOKENIZER_PREFIXES
from ..punctuation import TOKENIZER_SUFFIXES as BASE_TOKENIZER_SUFFIXES
from ..punctuation import TOKENIZER_INFIXES as BASE_TOKENIZER_INFIXES

_prefixes = ([r'\w{1,3}\$'] + BASE_TOKENIZER_PREFIXES)

_suffixes = (BASE_TOKENIZER_SUFFIXES)

_infixes = ([r'(\w+-\w+(-\w+)*)'] +
             BASE_TOKENIZER_INFIXES
             )

TOKENIZER_PREFIXES = _prefixes
TOKENIZER_SUFFIXES = _suffixes
TOKENIZER_INFIXES = _infixes



# coding: utf-8
from __future__ import unicode_literals

import pytest


@pytest.mark.parametrize('string,lemma', [('affaldsgruppernes', 'affaldsgruppe'),
                                          ('detailhandelsstrukturernes', 'detailhandelsstruktur'),
                                          ('kolesterols', 'kolesterol'),
                                          ('åsyns', 'åsyn')])
def test_lemmatizer_lookup_assigns(da_tokenizer, string, lemma):
    tokens = da_tokenizer(string)
    assert tokens[0].lemma_ == lemma



# coding: utf8
from __future__ import unicode_literals

from ...symbols import POS, PUNCT, SYM, ADJ, CONJ, NUM, DET, ADV, ADP, X, VERB
from ...symbols import NOUN, PROPN, PART, INTJ, SPACE, PRON, AUX


TAG_MAP = {
    "ADJ": {POS: ADJ },
    "ADJ_CMPR": {POS: ADJ },
    "ADJ_INO": {POS: ADJ},
    "ADJ_SUP": {POS: ADJ},
    "ADV": {POS: ADV},
    "ADV_COMP": {POS: ADV},
    "ADV_I": {POS:  ADV},
    "ADV_LOC": {POS:  ADV},
    "ADV_NEG": {POS:  ADV},
    "ADV_TIME": {POS:  ADV},
    "CLITIC": {POS:  PART},
    "CON": {POS:  CONJ},
    "CONJ": {POS:  CONJ},
    "DELM": {POS:  PUNCT},
    "DET": {POS: DET},
    "FW": {POS: X},
    "INT": {POS:  INTJ},
    "N_PL": {POS: NOUN},
    "N_SING": {POS: NOUN},
    "N_VOC": {POS: NOUN},
    "NUM": {POS:  NUM},
    "P": {POS:  ADP},
    "PREV": {POS: ADP},
    "PRO": {POS:  PRON},
    "V_AUX": {POS:  AUX},
    "V_IMP": {POS:  VERB},
    "V_PA": {POS:  VERB},
    "V_PP": {POS:  VERB},
    "V_PRS": {POS:  VERB},
    "V_SUB": {POS:  VERB},
}



# coding: utf8
from __future__ import unicode_literals


AUXILIARY_VERBS_IRREG = {
    "suis": ("être",),
    "es": ("être",),
    "est": ("être",),
    "sommes": ("être",),
    "êtes": ("être",),
    "sont": ("être",),
    "étais": ("être",),
    "étais": ("être",),
    "était": ("être",),
    "étions": ("être",),
    "étiez": ("être",),
    "étaient": ("être",),
    "fus": ("être",),
    "fut": ("être",),
    "fûmes": ("être",),
    "fûtes": ("être",),
    "furent": ("être",),
    "serai": ("être",),
    "seras": ("être",),
    "sera": ("être",),
    "serons": ("être",),
    "serez": ("être",),
    "seront": ("être",),
    "serais": ("être",),
    "serait": ("être",),
    "serions": ("être",),
    "seriez": ("être",),
    "seraient": ("être",),
    "sois": ("être",),
    "soit": ("être",),
    "soyons": ("être",),
    "soyez": ("être",),
    "soient": ("être",),
    "fusse": ("être",),
    "fusses": ("être",),
    "fût": ("être",),
    "fussions": ("être",),
    "fussiez": ("être",),
    "fussent": ("être",),
    "étant": ("être",),
    "ai": ("avoir",),
    "as": ("avoir",),
    "a": ("avoir",),
    "avons": ("avoir",),
    "avez": ("avoir",),
    "ont": ("avoir",),
    "avais": ("avoir",),
    "avait": ("avoir",),
    "avions": ("avoir",),
    "aviez": ("avoir",),
    "avaient": ("avoir",),
    "eus": ("avoir",),
    "eut": ("avoir",),
    "eûmes": ("avoir",),
    "eûtes": ("avoir",),
    "eurent": ("avoir",),
    "aurai": ("avoir",),
    "auras": ("avoir",),
    "aura": ("avoir",),
    "aurons": ("avoir",),
    "aurez": ("avoir",),
    "auront": ("avoir",),
    "aurais": ("avoir",),
    "aurait": ("avoir",),
    "aurions": ("avoir",),
    "auriez": ("avoir",),
    "auraient": ("avoir",),
    "aie": ("avoir",),
    "aies": ("avoir",),
    "ait": ("avoir",),
    "ayons": ("avoir",),
    "ayez": ("avoir",),
    "aient": ("avoir",),
    "eusse": ("avoir",),
    "eusses": ("avoir",),
    "eût": ("avoir",),
    "eussions": ("avoir",),
    "eussiez": ("avoir",),
    "eussent": ("avoir",),
    "ayant": ("avoir",)
}
